resource_name :infoscale_deploy
include Veritas_Infoscale::Install
require 'chef/log'
Logger = Chef::Log

action :install do
    install_path = node['veritas_infoscale']['install_script']
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = ENV['HOME']
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_install" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/install.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/install.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/install.rsp" do
        source 'install.response.erb'
        variables(
            :prod => node['veritas_infoscale']['prod'],
            :keyless =>	node['veritas_infoscale']['keyless'],
            :license => node['veritas_infoscale']['license'],
            :licensefile => node['veritas_infoscale']['licensefile'],
            :systems =>	node['veritas_infoscale']['systems'],
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
            :noipc => IsAttributeBool(node['veritas_infoscale']['noipc'], 1, "noipc"),
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs"),
            :patch_path => node['veritas_infoscale']['patch_path'],
            :edgeserver_host => node['veritas_infoscale']['edgeserver_host'],
            :edgeserver_port => node['veritas_infoscale']['edgeserver_port'],
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/install.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_install' do
        command "#{node['veritas_infoscale']['install_script']} -responsefile #{responsefile_path}/install.rsp"
    end

    #Move response file path
    ruby_block "post_install" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "install.rsp")
            end
        end
    end
end

action :configure do
    install_path = !(::File.exist?('/opt/VRTS/install/installer')) ? node['veritas_infoscale']['install_script'] : '/opt/VRTS/install/installer'
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_configure" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/configure.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/configure.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/configure.rsp" do
        source 'configure.response.erb'
        variables(
            :systems => node['veritas_infoscale']['systems'],
            :prod => node['veritas_infoscale']['prod'],
            :activecomponent =>	node['veritas_infoscale']['activecomponent'],
            :keyless =>	node['veritas_infoscale']['keyless'],
            :license =>	node['veritas_infoscale']['license'],
            :licensefile => node['veritas_infoscale']['licensefile'],
            :keyfile =>	node['veritas_infoscale']['keyfile'],
            :rsh =>	IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :tmppath => node['veritas_infoscale']['tmppath'],
            :noipc => IsAttributeBool(node['veritas_infoscale']['noipc'], 1, "noipc"),
            :logpath =>	node['veritas_infoscale']['logpath'],
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs"),
            :donotreconfigurevcs =>	IsAttributeBool(node['veritas_infoscale']['donotreconfigurevcs'], 1, "donotreconfigurevcs"),
            :donotreconfigurefencing =>	IsAttributeBool(node['veritas_infoscale']['donotreconfigurefencing'], 1, "donotreconfigurefencing"),
            :fencing_option => node['veritas_infoscale']['fencing_option'],
            :fencing_newdg_disks => node['veritas_infoscale']['fencing_newdg_disks'],
            :fencing_dgname => node['veritas_infoscale']['fencing_dgname'],
            :fencing_config_cpagent => IsAttributeBool(node['veritas_infoscale']['fencing_config_cpagent'], 1, "fencing_config_cpagent"),
            :fencing_cpagentgrp => node['veritas_infoscale']['fencing_cpagentgrp'],
            :fencing_cpagent_monitor_freq => node['veritas_infoscale']['fencing_cpagent_monitor_freq'],
            :fencing_auto_refresh_reg => IsAttributeBool(node['veritas_infoscale']['fencing_auto_refresh_reg'], 1, "fencing_auto_refresh_reg"),
            :clusterid => node['veritas_infoscale']['clusterid'],
            :clustername =>	node['veritas_infoscale']['clustername'],
            :allowcomms => IsAttributeBool(node['veritas_infoscale']['allowcomms'], 1, "allowcomms"),
            :fencingenabled => IsAttributeBool(node['veritas_infoscale']['fencingenabled'], 1, "fencingenabled"),
            :lltoverudp => IsAttributeBool(node['veritas_infoscale']['lltoverudp'], 1, "lltoverudp"),
            :heartbeat_udplink_address => node['veritas_infoscale']['heartbeat_udplink_address'],
            :heartbeat_udplink_port => node['veritas_infoscale']['heartbeat_udplink_port'],
            :heartbeat_udplink_netmask => node['veritas_infoscale']['heartbeat_udplink_netmask'],
            :heartbeat_udplinklowpri_address => node['veritas_infoscale']['heartbeat_udplinklowpri_address'],
            :heartbeat_udplinklowpri_port => node['veritas_infoscale']['heartbeat_udplinklowpri_port'],
            :heartbeat_udplinklowpri_netmask => node['veritas_infoscale']['heartbeat_udplinklowpri_netmask'],
            :lltoverrdma => IsAttributeBool(node['veritas_infoscale']['lltoverrdma'], 1, "lltoverrdma"),
            :heartbeat_rdmalink_address => node['veritas_infoscale']['heartbeat_rdmalink_address'],
            :heartbeat_rdmalink_port => node['veritas_infoscale']['heartbeat_rdmalink_port'],
            :heartbeat_rdmalink_netmask => node['veritas_infoscale']['heartbeat_rdmalink_netmask'],
            :heartbeat_rdmalinklowpri_address => node['veritas_infoscale']['heartbeat_rdmalinklowpri_address'],
            :heartbeat_rdmalinklowpri_port => node['veritas_infoscale']['heartbeat_rdmalinklowpri_port'],
            :heartbeat_rdmalinklowpri_netmask => node['veritas_infoscale']['heartbeat_rdmalinklowpri_netmask'],
            :csgnic	=>	node['veritas_infoscale']['csgnic'],
            :csgvip =>	node['veritas_infoscale']['csgvip'],
            :csgnetmask =>	node['veritas_infoscale']['csgnetmask'],
            :smtpserver => node['veritas_infoscale']['smtpserver'],
            :smtprecp => node['veritas_infoscale']['smtprecp'],
            :smtprsev => node['veritas_infoscale']['smtprsev'],
            :snmpport => node['veritas_infoscale']['snmpport'],
            :snmpcons => node['veritas_infoscale']['snmpcons'],
            :snmpcsev => node['veritas_infoscale']['snmpcsev'],
            :eat_security => IsAttributeBool(node['veritas_infoscale']['eat_security'], 1, "eat_security"),
            :secusrgrps => node['veritas_infoscale']['secusrgrps'],
            :defaultaccess => IsAttributeBool(node['veritas_infoscale']['defaultaccess'], 1, "defaultaccess"),
            :eat_security_fips => IsAttributeBool(node['veritas_infoscale']['eat_security_fips'], 1, "eat_security_fips"),
            :heartbeat_links_interface => node['veritas_infoscale']['heartbeat_links_interface'],
            :lopri_link_interface => node['veritas_infoscale']['lopri_link_interface'],
            :gconetmask => node['veritas_infoscale']['gconetmask'],
            :gconic =>	node['veritas_infoscale']['gconic'],
            :gcovip => node['veritas_infoscale']['gcovip'],
            :userenpw => node['veritas_infoscale']['userenpw'],
            :username => node['veritas_infoscale']['username'],
            :userpriv => node['veritas_infoscale']['userpriv'],
            :edgeserver_host => node['veritas_infoscale']['edgeserver_host'],
            :edgeserver_port => node['veritas_infoscale']['edgeserver_port'],
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/configure.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_configure' do
        command "#{install_path} -responsefile #{responsefile_path}/configure.rsp"
    end

    #Move response file path
    ruby_block "post_configure" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "configure.rsp")
            end
        end
    end
end

action :uninstall do
    install_path = !(::File.exist?('/opt/VRTS/install/installer')) ? node['veritas_infoscale']['install_script'] : '/opt/VRTS/install/installer'
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_uninstall" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/uninstall.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/uninstall.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/uninstall.rsp" do
        source 'uninstall.response.erb'
        variables(
            :prod => node['veritas_infoscale']['prod'],
            :systems => node['veritas_infoscale']['systems'],
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
            :vm_no_open_vols => IsAttributeBool(node['veritas_infoscale']['vm_no_open_vols'], 1, "vm_no_open_vols"),
            :fencing_delete_client_on_cps => IsAttributeBool(node['veritas_infoscale']['fencing_delete_client_on_cps'], 1, "fencing_delete_client_on_cps"),
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs")

        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/uninstall.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_uninstall' do
        command "#{install_path} -responsefile #{responsefile_path}/uninstall.rsp"
    end

    #Move response file path
    ruby_block "post_uninstall" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "uninstall.rsp")
            end
        end
    end
end

action :fullupgrade do
    install_path = node['veritas_infoscale']['install_script']
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_fullupgrade" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/fullupgrade.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/fullupgrade.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/fullupgrade.rsp" do
        source 'fullupgrade.response.erb'
        variables(
            :systems => node['veritas_infoscale']['systems'],
            :allowcomms => IsAttributeBool(node['veritas_infoscale']['allowcomms'], 1, "allowcomms"),
            :vr => IsAttributeBool(node['veritas_infoscale']['vr'], 1, "vr"),
            :licensefile => node['veritas_infoscale']['licensefile'],
            :eat_recreate_creds => IsAttributeBool(node['veritas_infoscale']['eat_recreate_creds'], 1, "eat_recreate_creds"),
            :disable_dmp_native_support => IsAttributeBool(node['veritas_infoscale']['disable_dmp_native_support'], 1, "disable_dmp_native_support"),
            :client_vxfen_warning => IsAttributeBool(node['veritas_infoscale']['client_vxfen_warning'], 1, "client_vxfen_warning"),
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
            :noipc => IsAttributeBool(node['veritas_infoscale']['noipc'], 1, "noipc"),
            :vm_no_open_vols => IsAttributeBool(node['veritas_infoscale']['vm_no_open_vols'], 1, "vm_no_open_vols"),
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs"),
            :patch_path => node['veritas_infoscale']['patch_path'],
            :edgeserver_host => node['veritas_infoscale']['edgeserver_host'],
            :edgeserver_port => node['veritas_infoscale']['edgeserver_port'],
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/fullupgrade.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_fullupgrade' do
        command "#{node['veritas_infoscale']['install_script']} -responsefile #{responsefile_path}/fullupgrade.rsp"
    end

    #Move response file path
    ruby_block "post_fullupgrade" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "fullupgrade.rsp")
            end
        end
    end
end

action :rollingupgrade do
    install_path = node['veritas_infoscale']['install_script']
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_rollingupgrade" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/rollingupgrade.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/rollingupgrade.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    #rolling upgrade phase 1 order check
    phase1_order = node['veritas_infoscale']['phase1_order']
    system_list = [node['veritas_infoscale']['systems']].flatten
    if (verify_phase1_order(phase1_order,system_list) != 0)
        Logger.warn("Attribute phase1_order not defined in correct format")
        phase1_order = {}
    end

    template "#{responsefile_path}/rollingupgrade.rsp" do
        source 'rollingupgrade.response.erb'
        variables(
            :systems => node['veritas_infoscale']['systems'],
            :allowcomms => IsAttributeBool(node['veritas_infoscale']['allowcomms'], 1, "allowcomms"),
            :vr => IsAttributeBool(node['veritas_infoscale']['vr'], 1, "vr"),
            :licensefile => node['veritas_infoscale']['licensefile'],
            :eat_recreate_creds => IsAttributeBool(node['veritas_infoscale']['eat_recreate_creds'], 1, "eat_recreate_creds"),
            :rollingupgrade_phase2 => IsAttributeBool(node['veritas_infoscale']['rollingupgrade_phase2'], 1, "rollingupgrade_phase2"),
            :phase1_order => phase1_order,
            :disable_dmp_native_support => IsAttributeBool(node['veritas_infoscale']['disable_dmp_native_support'], 1, "disable_dmp_native_support"),
            :client_vxfen_warning => IsAttributeBool(node['veritas_infoscale']['client_vxfen_warning'], 1, "client_vxfen_warning"),
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
            :noipc => IsAttributeBool(node['veritas_infoscale']['noipc'], 1, "noipc"),
            :vm_no_open_vols => IsAttributeBool(node['veritas_infoscale']['vm_no_open_vols'], 1, "vm_no_open_vols"),
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs"),
            :patch_path => node['veritas_infoscale']['patch_path'],
            :edgeserver_host => node['veritas_infoscale']['edgeserver_host'],
            :edgeserver_port => node['veritas_infoscale']['edgeserver_port'],
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/rollingupgrade.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_rollingupgrade' do
        command "#{node['veritas_infoscale']['install_script']} -responsefile #{responsefile_path}/rollingupgrade.rsp"
    end

    #Move response file path
    ruby_block "post_rollingupgrade" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "rollingupgrade.rsp")
            end
        end
    end
end


action :patch_upgrade do
    install_path = node['veritas_infoscale']['install_script']
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_patchupgrade" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/patch_upgrade.rsp")
                search = "'" 
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/patch_upgrade.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/patch_upgrade.rsp" do
        source 'patch_upgrade.response.erb'
        variables(
            :systems => node['veritas_infoscale']['systems'],
            :allowcomms => IsAttributeBool(node['veritas_infoscale']['allowcomms'], 1, "allowcomms"),
            :vr => IsAttributeBool(node['veritas_infoscale']['vr'], 1, "vr"),
            :eat_recreate_creds => IsAttributeBool(node['veritas_infoscale']['eat_recreate_creds'], 1, "eat_recreate_creds"),
            :client_vxfen_warning => IsAttributeBool(node['veritas_infoscale']['client_vxfen_warning'], 1, "client_vxfen_warning"),
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
            :noipc => IsAttributeBool(node['veritas_infoscale']['noipc'], 1, "noipc"),
            :vm_no_open_vols => IsAttributeBool(node['veritas_infoscale']['vm_no_open_vols'], 1, "vm_no_open_vols"),
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs")
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/patch_upgrade.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_patchupgrade' do
        command "#{node['veritas_infoscale']['install_script']} -responsefile #{responsefile_path}/patch_upgrade.rsp"
    end

    #Move response file path
    ruby_block "post_patch_upgrade" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "patch_upgrade.rsp")
            end
        end
    end
end

action :license do
    install_path = !(::File.exist?('/opt/VRTS/install/installer')) ? node['veritas_infoscale']['install_script'] : '/opt/VRTS/install/installer'
    responsefile_path = node['veritas_infoscale']['responsefile_path']
    default_path = "/opt/VRTS/install/chef"
    responsefile_path,file_exists = get_responsefile_path(responsefile_path, default_path)
    if (file_exists == false)
        raise "The path specified in attribute responsefile_path does not exist"
    end
    ruby_block "pre_license" do
        block do
            installer_ret = verify_install_script(install_path)
            if installer_ret == 1
                raise "Attribute install_script is empty or the installer script does not exist"
            end
        end
    end

    #replace all single quotes with double quotes to change in JSON form
    ruby_block "editing response file" do
        block do
            if ::File.exist?("#{responsefile_path}/license.rsp")
                search = "'"
                replace = '"'
                fp = Chef::Util::FileEdit.new("#{responsefile_path}/license.rsp")
                fp.search_file_replace(search, replace)
                fp.write_file
            end
        end
    end

    template "#{responsefile_path}/license.rsp" do
        source 'license.response.erb'
        variables(
            :prod => node['veritas_infoscale']['prod'],
            :keyless => node['veritas_infoscale']['keyless'],
            :license => node['veritas_infoscale']['license'],
            :licensefile => node['veritas_infoscale']['licensefile'],
            :systems => node['veritas_infoscale']['systems'],
            :keyfile => node['veritas_infoscale']['keyfile'],
            :rsh => IsAttributeBool(node['veritas_infoscale']['rsh'], 1, "rsh"),
            :logpath => node['veritas_infoscale']['logpath'],
            :tmppath => node['veritas_infoscale']['tmppath'],
            :noipc => IsAttributeBool(node['veritas_infoscale']['noipc'], 1, "noipc"),
            :uploadlogs => IsAttributeBool(node['veritas_infoscale']['uploadlogs'], 1, "uploadlogs")
        )
        mode '0644'
        action :create
    end

    #replace all double quotes with single quotes to avoid string interpolation
    ruby_block "editing response file" do
        block do
            search = '"'
            replace = "'"
            fp = Chef::Util::FileEdit.new("#{responsefile_path}/license.rsp")
            fp.search_file_replace(search, replace)
            fp.write_file
        end
    end

    execute 'veritas_license' do
        command "#{install_path} -responsefile #{responsefile_path}/license.rsp"
    end

    #Move response file path
    ruby_block "post_license" do
        block do
            if responsefile_path.eql?(ENV['HOME'])
                move_responsefile(responsefile_path, "license.rsp")
            end
        end
    end
end
